@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KITINERARY_PDFBARCODEUTIL_H
-#define KITINERARY_PDFBARCODEUTIL_H
+#pragma once
 
 #include "barcodedecoder.h"
 
@@ -22,4 +21,3 @@ namespace PdfBarcodeUtil
 
 }
 
-#endif // KITINERARY_PDFBARCODEUTIL_H
